Security Policy

Supported Versions

Only the latest released version of TimeDate receives security fixes.

| Version | Supported | | ------- | --------- | | latest | Yes | | older | No |

Reporting a Vulnerability

TimeDate handles date/time string parsing and may be used to process untrusted input. If you discover a security vulnerability, please do not report it publicly via a GitHub issue.

Instead, report it privately using one of these methods:

Please include as much detail as possible:

Disclosure Policy

This project follows the guidelines described at https://security.metacpan.org/docs/guides/security-policy-for-authors.html.